sqlite

package
v0.0.0-...-73ce370 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2017 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Init

func Init() error

Init initialize a SQLite provider and set it as the used provider

Types

type Provider

type Provider struct {
	dp.Provider
}

Provider implements the methods needed to manage a channel via a SQLite database

func (*Provider) CreateIndexes

func (p *Provider) CreateIndexes() (err error)

CreateIndexes create constrains and indexes on channels tables

Jump to